QueryProofCircuitInput

Struct QueryProofCircuitInput 

pub struct QueryProofCircuitInput<const MAX_DEPTH: usize> {
    pub pk: [EdwardsAffine; 7],
    pub pk_index: Fq,
    pub s: Fr,
    pub r: EdwardsAffine,
    pub merkle_root: Fq,
    pub depth: Fq,
    pub mt_index: Fq,
    pub siblings: [Fq; MAX_DEPTH],
    pub beta: Fr,
    pub rp_id: Fq,
    pub action: Fq,
    pub nonce: Fq,
}
The input for the circuit of the OPRF Query Proof π1.

TODO: Rename attribute names to match the Credential type.

Fields

pk: [EdwardsAffine; 7]

The AuthenticatorPublicKeySet represented as an array of Affine points.

pk_index: Fq

The index of the public key which will be used to sign the OPRF query from the AuthenticatorPublicKeySet.

s: Fr

The s part of the signature of the query with the public key at the pk_index.

r: EdwardsAffine

The r part of the signature of the query with the public key at the pk_index.

merkle_root: Fq

The root of the Merkle tree of the WorldIDRegistry contract.

depth: Fq

The depth of the Merkle tree of the WorldIDRegistry contract.

mt_index: Fq

The leaf index of the World ID in the Merkle tree of the WorldIDRegistry contract.

In the MerkleInclusionProof type, this is the leaf_index field.

siblings: [Fq; MAX_DEPTH]

The siblings of the Merkle proof of the account in the WorldIDRegistry contract.

beta: Fr

The (non-inverted) blinding factor of the OPRF query.

rp_id: Fq

The ID of the RP requesting the proof as registered in the RpRegistry contract.

TODO: Will require updates once the new RpRegistry is launched.

action: Fq

The action for the proof request. See ProofRequest for more details.

nonce: Fq

The nonce of the proof request. See ProofRequest for more details.