pub struct ZeroKnowledgeProof { /* private fields */ }Expand description
Encoded World ID Proof.
Internally, the first 4 elements are a compressed Groth16 proof
[a (G1), b (G2), b (G2), c (G1)]. Proofs also require the root hash of the Merkle tree
in the WorldIDRegistry as a public input. To simplify transmission, that root is encoded as the last element
with the proof.
The WorldIDVerifier.sol contract handles the decoding and verification.
Implementations
Sourceimpl ZeroKnowledgeProof
impl ZeroKnowledgeProof
Sourcepub const fn as_ethereum_representation(&self) -> [U256; 5]
pub const fn as_ethereum_representation(&self) -> [U256; 5]
Outputs the proof as a Solidity-friendly representation.
Sourcepub const fn from_ethereum_representation(value: [U256; 5]) -> Self
pub const fn from_ethereum_representation(value: [U256; 5]) -> Self
Initializes a proof from an encoded Solidity-friendly representation.
Sourcepub fn to_compressed_bytes(&self) -> Vec<u8> ⓘ
pub fn to_compressed_bytes(&self) -> Vec<u8> ⓘ
Converts the proof to compressed bytes (160 bytes total: 5 × 32 bytes).