pub struct EdDSAPublicKey {
pub pk: Affine<EdwardsConfig>,
}Expand description
A public key for the EdDSA signature scheme over the BabyJubJubCurve.
Fields
pk: Affine<EdwardsConfig>Implementations
Sourceimpl EdDSAPublicKey
impl EdDSAPublicKey
Sourcepub fn verify(
&self,
message: Fp<MontBackend<FrConfig, 4>, 4>,
signature: &EdDSASignature,
) -> bool
pub fn verify( &self, message: Fp<MontBackend<FrConfig, 4>, 4>, signature: &EdDSASignature, ) -> bool
Verify the signature against the given message and public key.
This verification function follows https://eprint.iacr.org/2020/1244.pdf to avoid common pitfalls. In particular, this uses a so-called “cofactored” verification, such that batched signature verification is possible.
The only assumption is that both the public key and the nonce point R are canonical, i.e., their encoding is using valid field elements, which must be checked during deserialization.
Sourcepub fn to_compressed_bytes(&self) -> Result<[u8; 32], Report>
pub fn to_compressed_bytes(&self) -> Result<[u8; 32], Report>
Serialize the public key to a compressed byte array.
Sourcepub fn from_compressed_bytes(bytes: [u8; 32]) -> Result<EdDSAPublicKey, Report>
pub fn from_compressed_bytes(bytes: [u8; 32]) -> Result<EdDSAPublicKey, Report>
Parse the public key from a byte array with the point in compressed format.