pub struct SessionNullifier { /* private fields */ }Expand description
A session nullifier for World ID Session proofs. It is analogous to a request nonce,
it does NOT guarantee uniqueness of a World ID as a Nullifier does.
This type is intended to be opaque for RPs. For an RP context, they should only
be concerned of this needing to be passthrough to the verifySession() contract function.
This type exists as an adaptation to be able to use the same ZK-circuit for both Uniqueness Proofs and Session Proofs, and it encompasses:
- the nullifier used as the proof output.
- a random action bound to the same proof.
The WorldIDVerifier.sol contract expects this as a uint256[2] array
use as_ethereum_representation() for conversion.
Future
Note the session nullifier exists only to support the same ZK-circuit than for Uniqueness Proofs; as World ID evolves to a different proving system which won’t require circuit precompiles, a new circuit MUST be created which does not generate a nullifier at all, and the input randomized action will not be required either.
Implementations
Sourceimpl SessionNullifier
impl SessionNullifier
Sourcepub const fn new(nullifier: FieldElement, action: FieldElement) -> Self
pub const fn new(nullifier: FieldElement, action: FieldElement) -> Self
Creates a new session nullifier.
Sourcepub const fn nullifier(&self) -> FieldElement
pub const fn nullifier(&self) -> FieldElement
Returns the nullifier value.
Sourcepub const fn action(&self) -> FieldElement
pub const fn action(&self) -> FieldElement
Returns the action value.
Sourcepub fn as_ethereum_representation(&self) -> [U256; 2]
pub fn as_ethereum_representation(&self) -> [U256; 2]
Returns the session nullifier as an Ethereum-compatible array for verifySession().
Format: [nullifier, action] matching the contract’s uint256[2] sessionNullifier.
Sourcepub fn from_ethereum_representation(value: [U256; 2]) -> Result<Self, String>
pub fn from_ethereum_representation(value: [U256; 2]) -> Result<Self, String>
Creates a session nullifier from an Ethereum representation.
Errors
Returns an error if the U256 values are not valid field elements.
Sourcepub fn to_compressed_bytes(&self) -> [u8; 64]
pub fn to_compressed_bytes(&self) -> [u8; 64]
Returns the 64-byte big-endian representation (2 x 32-byte field elements).