pub struct FieldElement(/* private fields */);Expand description
Represents a field element of the base field (Fq) in the World ID Protocol.
The World ID Protocol uses the BabyJubJub curve throughout. Note the
base field of BabyJubJub is the scalar field of the BN254 curve.
This wrapper ensures consistent serialization and deserialization of field elements, where string-based serialization is done with hex encoding and binary serialization is done with byte vectors.
Implementations
Sourceimpl FieldElement
impl FieldElement
Sourcepub fn to_be_bytes(&self) -> [u8; 32]
pub fn to_be_bytes(&self) -> [u8; 32]
Returns the 32-byte big-endian representation of this field element.
Sourcepub fn from_be_bytes(be_bytes: &[u8; 32]) -> Result<Self, PrimitiveError>
pub fn from_be_bytes(be_bytes: &[u8; 32]) -> Result<Self, PrimitiveError>
Constructs a field element from a 32-byte big-endian representation.
Unlike from_be_bytes_mod_order, this rejects values >= the field modulus.
Errors
Returns PrimitiveError::NotInField if the value is >= the field modulus.
Sourcepub fn from_arbitrary_raw_bytes(bytes: &[u8]) -> Self
pub fn from_arbitrary_raw_bytes(bytes: &[u8]) -> Self
Takes arbitrary raw bytes, hashes them with a byte-friendly gas-efficient hash function and reduces it to a field element.