Nullifier

Struct Nullifier 

pub struct Nullifier {
    pub inner: FieldElement,
}
A nullifier is a unique, one-time identifier derived from (user, rpId, action) that lets RPs detect duplicate actions without learning who the user is. Used with the contract’s verify() function.

Internally, this is a thin wrapper to identify explicitly a single nullifier. This wrapper is used to expose explicit canonical serialization which is critical for uniqueness.

Fields

inner: FieldElement

The FieldElement representing the nullifier.

Implementations

Source

impl Nullifier

pub const fn new(nullifier: FieldElement) -> Self

Initializes a new Nullifier from a FieldElement

pub fn as_number(&self) -> U256

Outputs the nullifier as a number. This is the recommended way of enforcing nullifier uniqueness.

Store this number directly to enforce uniqueness.

pub fn to_canonical_string(&self) -> String

Serializes a nullifier in a canonical string representation.

It is generally safe to do uniqueness on nullifiers treating them as strings if you always serialize them with this method. However, storing nullifiers as numbers instead is recommended.

Warning

Using a canonical representation is particularly important for nullifiers. Otherwise, different strings may actually represent the same field elements, which could result in a compromise of uniqueness.

Details

In particular, this method adds an explicit prefix, serializes the field element to a 32-byte hex padded string with only lowercase characters.

pub fn from_canonical_string(nullifier: String) -> Result<Self, PrimitiveError>

Deserializes a nullifier from a canonical string representation. In particular, this method will enforce all the required rules to ensure the value was canonically serialized.

For example, the following string representations are equivalently the same field element: 0xa, 0xA, 0x0A, this method will ensure a single representation exists for each field element.

Errors

Will return an error if any of the encoding conditions failed (e.g. invalid characters, invalid length, etc.)

Methods from Deref<Target = FieldElement>

pub const ZERO: Self

pub const ONE: Self

pub fn to_be_bytes(&self) -> [u8; 32]

Returns the 32-byte big-endian representation of this field element.

pub fn to_u256(&self) -> U256

Converts the field element to a U256.