pub struct SessionId {
pub commitment: FieldElement,
pub oprf_seed: FieldElement,
}Expand description
An identifier for a session (can be re-used).
A session allows RPs to ensure that it’s still the same World ID interacting with them across multiple interactions.
A SessionId is obtained after creating an initial session.
See the diagram below on how Session Proofs work, the SessionId and the r seed
Note that the action stored here is unrelated to the randomized action used
internally by SessionNullifiers — that randomized action exists only to ensure
the circuit’s nullifier output is unique per Session Proof.
Fields
commitment: FieldElementThe actual commitment being verified in the ZK-circuit.
It is computed as H(DS_C || leaf_index || session_id_r_seed), see
signal computed_id_commitment in oprf_nullifier.circom.
oprf_seed: FieldElementA random seed generated by the authenticator in the initial Uniqueness Proof.
This seed is the input to the OPRF Query to derive session_id_r_seed (r). It
is part of the session_id so the RP can provide it when requesting a Session Proof.
Important: Prefix
To ensure there are no collisions between the generated rs and the nullifiers
for Uniqueness Proofs (as they use the same OPRF Key and query structure), the
oprf_seeds, which are plugged as action in the Query Proof (see QueryProofCircuitInput),
MUST be prefixed with an explicit byte of 0x01. All other actions have a 0x00 byte prefix. This
collision avoidance is important because it ensures that any requests for nullifiers meant
for Uniqueness Proofs are always signed by the RP (otherwise, an RP signature for a Session Proof
could be used for requesting computation of any nullifier).
Re-derivation
The Authenticator can deterministically re-derive r from the OPRF nodes without
needing to cache r locally as:
r = OPRF(pk_rpId, DS_C || leafIndex || oprf_seed)Implementations
Sourceimpl SessionId
impl SessionId
Sourcepub fn new(
commitment: FieldElement,
oprf_seed: FieldElement,
) -> Result<Self, PrimitiveError>
pub fn new( commitment: FieldElement, oprf_seed: FieldElement, ) -> Result<Self, PrimitiveError>
Creates a new session id. Most uses should default to from_r_seed instead.
Errors
If the provided oprf_seed is not prefixed properly.
Sourcepub fn from_r_seed(
leaf_index: u64,
session_id_r_seed: FieldElement,
oprf_seed: FieldElement,
) -> Result<Self, PrimitiveError>
pub fn from_r_seed( leaf_index: u64, session_id_r_seed: FieldElement, oprf_seed: FieldElement, ) -> Result<Self, PrimitiveError>
Initializes a SessionId from the OPRF-output seed (r), and the oprf_seed
used as input for the OPRF computation.
This matches the logic in oprf_nullifier.circom for computing the commitment from the OPRF seed.
Seed (session_id_r_seed)
- The seed MUST be computationally indistinguishable from random, i.e. uniformly distributed because it uses OPRF.
- When computed, the OPRF nodes will use the same
oprfKeyIdfor the RP, with a different domain separator. - Requesting this seed requires a properly signed request from the RP and a complete query proof.
- The seed generation is based on a randomly generated seed used as an “action” in a Query Proof. Note
this
actionis different than the randomized action used internally bySessionNullifiers.
Sourcepub fn generate_oprf_seed<R: CryptoRng + RngCore>(rng: &mut R) -> FieldElement
pub fn generate_oprf_seed<R: CryptoRng + RngCore>(rng: &mut R) -> FieldElement
Generates a new Self::oprf_seed to initialize a new Session.
Sourcepub fn to_compressed_bytes(&self) -> [u8; 64]
pub fn to_compressed_bytes(&self) -> [u8; 64]
Returns the 64-byte big-endian representation (2 x 32-byte field elements).